@@ -240,7 +240,9 @@ def _multiframe_to_nifti(dicom_input, output_file):
     logger.info('Creating nifti')
 
     # Convert to nifti
-    nii_image = nibabel.Nifti1Image(full_block.squeeze(), affine)
+    if full_block.ndim > 3:  # do not squeeze single slice data
+        full_block = full_block.squeeze()
+    nii_image = nibabel.Nifti1Image(full_block, affine)
     timing_parameters = multiframe_dicom.SharedFunctionalGroupsSequence[0].MRTimingAndRelatedParametersSequence[0]
     first_frame = multiframe_dicom[Tag(0x5200, 0x9230)][0]
     common.set_tr_te(nii_image, float(timing_parameters.RepetitionTime),
@@ -292,7 +294,9 @@ def _singleframe_to_nifti(grouped_dicoms, output_file):
 
     logger.info('Creating nifti')
     # Convert to nifti
-    nii_image = nibabel.Nifti1Image(full_block.squeeze(), affine)
+    if full_block.ndim > 3:  # do not squeeze single slice data
+        full_block = full_block.squeeze()
+    nii_image = nibabel.Nifti1Image(full_block, affine)
     common.set_tr_te(nii_image, float(grouped_dicoms[0][0].RepetitionTime), float(grouped_dicoms[0][0].EchoTime))
 
     if output_file is not None:
